---
feature_story: FS_70_55_40_99
feature_title: splitting config files
feature_status: TEST
---

There is a need to split large config files primarily to reuse common config data.

At the moment, it is implemented via YAML extension `!include`, for example:

```yaml
SomePlugin.default:
    plugin_module_name: argrelay.plugin_delegator.SomePlugin
    plugin_class_name: SomePlugin
    plugin_config:
        !include "dst/env_name/plugin_config/SomePlugin.default.yaml"
```
